@@ -369,7 +369,7 @@ class NamedPythonViewServer(BasePythonViewServer):
             module = '.'.join(parts[:-1])
             name = parts[-1]
         except:
-            self.exception("compile_func_name")
+            self.exception("compile_func_name", log_traceback=False)
 
         try:
             __import__(module)
@@ -379,7 +379,7 @@ class NamedPythonViewServer(BasePythonViewServer):
                 raise ValueError("Loaded version {0!r} did not match "
                         "expected version {1!r}".format(f_ver, version))
         except:
-            self.exception("compile_load")
+            self.exception("compile_load", log_traceback=False)
 
         return f
 
